@@ -27,15 +27,15 @@
 class VerticalText : public QWidget
 {
    public:
-      VerticalText(QWidget * parent, const QString&, Qt::WFlags f = 0);
+      explicit VerticalText(QWidget * parent, const QString&, Qt::WindowFlags f = {});
       ~VerticalText();
 
       void setText(const QString& text);
-      QSize sizeHint() const;
+      QSize sizeHint() const override;
       QSizePolicy sizePolicy () const;
-      QSize minimumSizeHint() const;
+      QSize minimumSizeHint() const override;
    protected:
-      void paintEvent ( QPaintEvent * event );
+      void paintEvent ( QPaintEvent * event ) override;
 
    private:
       QString m_labelText;
